#!/bin/bash
#-----------------------------------------------------------#
# シェル名: additional.sh
#-----------------------------------------------------------#
# 処理概要: 追加アプリケーションのインストール
#-----------------------------------------------------------#
# 2009/9/9 SoSO
#-----------------------------------------------------------#

#-----------------------------------------------------------#
# 前処理
#-----------------------------------------------------------#
cd $(dirname $0)
SCRPT_HOME=$(pwd)

# 共通設定ファイルの読み込み
COMMON_SH=$SCRPT_HOME/../common/common.sh
if [ -f $COMMON_SH ]; then
	. $COMMON_SH
else
	echo "[エラー] ${COMMON_SH} が存在しません。"
	exit 1
fi

# ログ
LOG=$_ADD_LOG_
LogStart $LOG

#-----------------------------------------------------------#
# main
#-----------------------------------------------------------#
echo ""
echo " ■ 追加アプリケーションのインストール (Fedora 11)"
echo ""
echo " マルチメディア系アプリケーション、コーデックのインストールを行います。"
echo " 著作権保護された DVD や MP3 など、さまざまな形式の動画・音声ファイル"
echo " の再生に対応します。"
echo ""
echo " 注意"
echo "  本プログラムは [カスタマイズの実行.sh] の後に実行する必要があります。"
echo "  また、ネットワークに接続可能な状態で実行してください。"
echo ""

LOCK_FILE=/var/lock/subsys/scustoma
if [ -f $LOCK_FILE ]; then
    echo " このスクリプトは、他のプロセスで実行中か、"
    echo " あるいは、前回の実行途中で中断した可能性があります。"
    echo 
    echo -n " 強制的に実行しますか? [y/n] "
else
    echo -n " 開始してもよろしいですか。[y/n] "
fi
touch $LOCK_FILE

read line
if [ "$line" != "y" ] && [ "$line" != "yes" ] && [ "$line" != "Y" ] && [ "$line" != "YES" ] ; then
		echo
    echo "中止しました。"
    rm -f $LOCK_FILE
    sleep 3
    exit
fi
echo

cd $SCRPT_HOME/additional

# gpk-update-icon 無効化
pkill gpk-update-icon

# Livna リポジトリを登録
#  livna は rpmfusion に統合されたため本来は必要ないのですが、
#  libdvdcss パッケージが現在 livna にしか存在しないため登録しています。
rpm -U livna-release-*.rpm >> $LOG 2>&1
rpm -q livna-release > /dev/null 2>&1
if [ $? -eq 0 ]; then
    rpm --import /etc/pki/rpm-gpg/RPM-GPG-KEY-livna >> $LOG 2>&1
else
    LogWrite $LOG "[エラー] livna-release のインストールに失敗"
fi

# [バグ対応] gstreamer-plugins-farsight をアップデート(gstreamer-plugins-good に移行)
# gstreamer-plugins-bad と gstreamer-plugins-farsight の衝突を回避するため。

rpm -q gstreamer-plugins-farsight >> /dev/null 2>&1
if [ $? -eq 0 ]; then
	yum --enablerepo=livna,rpmfusion-free,rpmfusion-nonfree --disablerepo=linuxmania-support \
		-y update gstreamer-plugins-farsight | tee -a $LOG

	rpm -q gstreamer-plugins-good >> /dev/null 2>&1
	if [ $? -eq 0 ]; then
		LogWrite $LOG "[OK] gstreamer-plugins-farsight のアップデートに成功"
	else
		LogWrite $LOG "[エラー] gstreamer-plugins-farsight のアップデートに失敗"
		echo
		echo "インストールに失敗しました。"
		echo "Enter キーで終了します。"
		read dummy
		exit 1
	fi
fi

echo

# [バグ対応] mozilla-vlc を入れないように変更
#   mp3 ファイルへのリンクをクリックすると Firefox が落ちてしまう問題を回避するため。
#   mozilla-vlc がない場合 totem で再生されます。
yum --enablerepo=livna,rpmfusion-free,rpmfusion-nonfree --disablerepo=linuxmania-support -y install libdvdcss \
	vlc \
	xine-ui xine-lib-extras-freeworld \
	audacious-plugins-* \
	gstreamer-plugins-ugly gstreamer-plugins-bad \
    gstreamer-ffmpeg ffmpeg \
    k3b-extras-freeworld | tee -a $LOG

rpm -q libdvdcss vlc xine-ui xine-lib-extras-freeworld \
    audacious-plugins-* gstreamer-plugins-ugly gstreamer-plugins-bad gstreamer-ffmpeg ffmpeg \
    k3b-extras-freeworld > /dev/null 2>&1

if [ $? -ne 0 ]; then
	rm -f $LOCK_FILE >> $LOG 2>&1
	LogWrite $LOG "[エラー] 追加アプリケーションのインストールに失敗"
	echo
	echo "インストールに失敗しました。"
	echo "Enter キーで終了します。"
	read dummy
	exit 1
else
	LogWrite $LOG "[OK] 追加アプリケーションのインストールに成功"
	#ReplaceFile "s/Exec=xine/Exec=env LANG=en xine/" "/usr/share/applications/livna-xine.desktop"
fi

# 動画プレイヤー起動設定を /etc/skel 以下にコピー
mkdir -p /etc/skel/.local
\cp -fpR common-conf/local/* /etc/skel/.local/ >> $LOG 2>&1   
mkdir -p /etc/skel/.gconf
\cp -fpR common-conf/gconf/* /etc/skel/.gconf/ >> $LOG 2>&1   

# 各ディレクトリにある TRANS.TBL ファイルを削除
find /etc/skel -name TRANS.TBL -exec rm -f {} \;

# 動画プレイヤー起動設定を ユーザのホーム 以下にコピー
user_names=($(cat /etc/passwd | grep -e "/home" -e "^root" | cut -d : -f 1)) >> $LOG 2>&1   
user_homes=($(cat /etc/passwd | grep -e "/home" -e "^root" | cut -d : -f 6)) >> $LOG 2>&1   
user_count=${#user_names[@]} >> $LOG 2>&1   
i=0
while [ $i -lt $user_count ];
do
    \cp -fpR common-conf/local/* ${user_homes[$i]}/.local/ >> $LOG 2>&1
    \cp -fpR common-conf/gconf/* ${user_homes[$i]}/.gconf/ >> $LOG 2>&1

    # 各ディレクトリにある TRANS.TBL ファイルを削除
    find ${user_homes[$i]}/.local/ -name TRANS.TBL -exec rm -f {} \;
    find ${user_homes[$i]}/.gconf/ -name TRANS.TBL -exec rm -f {} \;

    i=$(expr $i + 1)
done

# カスタマイズの実行ユーザ
su -c 'gconftool-2 --load gconf-dump/media-autoplay.entries' $LOGNAME >> /dev/null 2>&1

# gpk-update-icon 有効化
cd $(cat /etc/passwd | grep -e "^$LOGNAME:" | cut -d : -f 6) >> /dev/null 2>&1
su -c 'gpk-update-icon &' $LOGNAME >> /dev/null 2>&1


echo ""
echo "インストールが完了しました。"
echo ""
echo "Enter キーでウィンドウが閉じます。"
echo ""

read line
rm -f $LOCK_FILE

#-----------------------------------------------------------#
# 後処理
#-----------------------------------------------------------#
LogEnd $LOG

